@@ -185,7 +185,7 @@ def histplot(
             binnorms = binnorms[0]
         return binnorms
 
-    if density:
+    if density or binwnorm is not None:
         density_arr = get_density(h, density, binwnorm)
         if stack and densitymode == "stack":
             h = get_stack(h)
@@ -374,6 +374,8 @@ def hist2dplot(
         cax = append_axes(ax, size=cbarsize, pad=cbarpad, position=cbarpos)
         plt.colorbar(pc, cax=cax)
 
+    plt.sca(ax)
+
     if labels is not None:
         if np.array_equiv(H, labels):
             _labels = labels
